# hastrofunc

This is a simple package containing useful functions for Hannah's astronomy research. 

<!-- This should be commented out. You can use [Github-flavored Markdown](https://guides.github.com/features/mastering-markdown/) to write your content. -->
